@@ -6,17 +6,17 @@
 # can be included in any Rcmdr plug-in package to cause the package to load
 # the Rcmdr if it is not already loaded
 
-.First.lib <- function(libname, pkgname){
-    if (!interactive()) return()
-    Rcmdr <- options()$Rcmdr
-    plugins <- Rcmdr$plugins
-    if ((!pkgname %in% plugins) && !getRcmdr("autoRestart")) {
-        Rcmdr$plugins <- c(plugins, pkgname)
-        options(Rcmdr=Rcmdr)
-        closeCommander(ask=FALSE, ask.save=TRUE)
-        Commander()
+.onAttach <- function(libname, pkgname){
+        if (!interactive()) return()
+        Rcmdr <- options()$Rcmdr
+        plugins <- Rcmdr$plugins
+        if ((!pkgname %in% plugins) && !getRcmdr("autoRestart")) {
+                Rcmdr$plugins <- c(plugins, pkgname)
+                options(Rcmdr=Rcmdr)
+                closeCommander(ask=FALSE, ask.save=TRUE)
+                Commander()
         }
-    }
+}
 
     
    
@@ -185,7 +185,7 @@ freq1 <- as.numeric(tclvalue(freqVariable))
   
           closeDialog()
 	command <- paste(dsnameValue, "<- shape1(", ActiveDataSet(), "$", x,
-         ",freq=",freq1,
+         ",frequency=",freq1,
             ")", sep="")
 	justDoIt(command)
         logger(command)
